append: Append to list of boxes (S3)

View source: R/boxGrobs_s3_append.R

appendR Documentation

Append to list of boxes (S3)

Description

Append an element to a list of boxes, preserving attributes/class. Masks 'base::append' to support S3 dispatch.

Usage

append(x, values, after = length(x))

## Default S3 method:
append(x, values, after = length(x))

## S3 method for class 'Gmisc_list_of_boxes'
append(x, values, after = length(x))

Arguments

x

A 'Gmisc_list_of_boxes' or 'list'.

values

The object(s) to append. If a single 'boxGrob' is provided, it is wrapped in a list.

after

Subscript, after which the values are to be appended.

Value

Updated list of boxes.

See Also

Other flowchart components: align(), boxGrob(), boxHeaderGrob(), boxPropGrob(), boxShapes, connectGrob(), coords(), distance(), flowchart(), insert(), move(), moveBox(), spread()


Gmisc documentation built on March 6, 2026, 9:09 a.m.