insert: Insert element into a list of boxes (S3)

View source: R/boxGrobs_s3_append.R

insertR Documentation

Insert element into a list of boxes (S3)

Description

Inserts a box into a list of boxes and positions it relative to the surrounding boxes.

Usage

insert(x, element, ..., after = NULL, before = NULL)

## Default S3 method:
insert(x, element, ..., after = NULL, before = NULL)

## S3 method for class 'Gmisc_list_of_boxes'
insert(x, element, ..., after = NULL, before = NULL)

Arguments

x

A 'Gmisc_list_of_boxes'.

element

The new box object to insert.

...

Not used.

after

The name or index of the box after which to insert.

before

The name or index of the box before which to insert.

Value

The updated list of boxes with the new element inserted.

See Also

Other flowchart components: align(), append(), boxGrob(), boxHeaderGrob(), boxPropGrob(), boxShapes, connectGrob(), coords(), distance(), flowchart(), move(), moveBox(), spread()


Gmisc documentation built on March 6, 2026, 9:09 a.m.