Performs a structural change analysis on diferent layer models to find points where a change in the sequence might be occuring.
Details
The example data given is intended to show the structure needed for input data. The user should follow this structure, which in general corresponds with a data frame with a sequence in the first column and the observed/measured values in the second column
See also
Other layer detection:
RI(),
T2_stat(),
T_stat(),
cp_aic_eta(),
cp_layers(),
layers_window(),
sc_layers()