Calculates the intraclass correlation coefficient (RI) for a perforation log, and shows the locations where this coefficient is higher than 0.7 and 0.8. The coefficient is used to find layer boundaries in a perforation log.
Value
ggplot and plotly objects showing the RI statistic and lines marking the critical values of 0.7 and 0.8, and suggested boundaries
Details
The example data given is intended to show the structure needed for input data. The user should follow this structure, which in general corresponds with a data frame with a sequence in the first column and the observed/measured values in the second column
References
Mora, R. (2013). Uso de metodos estadisticos para la determinacion de capas homogeneas de suelos volcanicos en un sitio de las laderas del Volcan Irazu, Cartago, Costa Rica. - Rev. Geol. Amer. Central, 49: 101-108.
See also
Other layer detection:
T2_stat(),
T_stat(),
cp_aic_eta(),
cp_layers(),
layers_window(),
sc_bic(),
sc_layers()
Examples
RI(DPM_data, k = 6)
#> Warning: `aes_string()` was deprecated in ggplot2 3.0.0.
#> ℹ Please use tidy evaluation idioms with `aes()`.
#> ℹ See also `vignette("ggplot2-in-packages")` for more information.
#> ℹ The deprecated feature was likely used in the GMisc package.
#> Please report the issue at <https://github.com/maxgav13/GMisc/issues>.
#> $GGPLOT
#>
#> $PLOTLY
#>
#> $Bounds.7
#> [1] 3.8 7.5 7.9 8.7 9.4 9.7
#>
#> $Bounds.8
#> [1] 7.9 9.4 9.7
#>