View source: R/boxGrobs_s3_append.R
| append | R Documentation |
Append an element to a list of boxes, preserving attributes/class. Masks 'base::append' to support S3 dispatch.
append(x, values, after = length(x))
## Default S3 method:
append(x, values, after = length(x))
## S3 method for class 'Gmisc_list_of_boxes'
append(x, values, after = length(x))
x |
A 'Gmisc_list_of_boxes' or 'list'. |
values |
The object(s) to append. If a single 'boxGrob' is provided, it is wrapped in a list. |
after |
Subscript, after which the values are to be appended. |
Updated list of boxes.
Other flowchart components:
align(),
boxGrob(),
boxHeaderGrob(),
boxPropGrob(),
boxShapes,
connectGrob(),
coords(),
distance(),
flowchart(),
insert(),
move(),
moveBox(),
spread()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.