| flowchart | R Documentation |
This function initializes a flowchart object, which is essentially a list of boxes with the class 'Gmisc_list_of_boxes'. It serves as the starting point for the S3 pipeline, allowing for fluent chaining of ['align'], ['spread'], ['move'], and ['connect'] operations.
flowchart(..., default_box_fn = boxGrob)
... |
Either a set of ['boxGrob'] objects, text strings, or lists of these. Text strings will be automatically wrapped in ['boxGrob'] (or 'default_box_fn'). |
default_box_fn |
The function to use for converting text/content into a box (default: ['boxGrob']). |
A 'list' of class 'Gmisc_list_of_boxes'.
Other flowchart components:
align(),
append(),
boxGrob(),
boxHeaderGrob(),
boxPropGrob(),
boxShapes,
connectGrob(),
coords(),
distance(),
insert(),
move(),
moveBox(),
spread()
library(grid)
grid.newpage()
# Create a flowchart with auto-conversion of text
fc <- flowchart(
start = "Start",
process = "Process",
end = "End"
)
# Use the pipeline
fc |>
align(axis = "y") |>
connect("start", "process", type = "vertical") |>
connect("process", "end", type = "vertical") |>
print()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.