Compute uniformity and curvature coefficients from a grain-size distribution
Source:R/USCS.R
grainSize.coefs.RdCalculates the uniformity coefficient and the curvature coefficient from percent passing data. The characteristic diameters can be supplied directly or derived from sieve numbers or particle sizes.
Arguments
- percent
Numeric vector of percent passing values (0–100).
- sieve
Numeric vector of ASTM sieve numbers. Used when
sizeis not provided. DefaultNA.- size
Numeric vector of particle sizes (mm if
metric = TRUE, inches otherwise). DefaultNA.- D10
Diameter at 10 percent passing. If
NA(default) it is interpolated from the data.- D30
Diameter at 30 percent passing. If
NA(default) it is interpolated from the data.- D60
Diameter at 60 percent passing. If
NA(default) it is interpolated from the data.- metric
Logical. If
TRUE(default) sizes are in millimetres.
Details
This function is taken from the "geotech" package from James Kaklamanos (curvature coefficient).
See also
Other soil mechanics, classification:
Dsize(),
USCS(),
USCS.coarse.symbol(),
USCS.fine.symbol(),
percentComponents(),
size.from.sieve()