View source: R/boxGrobs_s3_append.R
| insert | R Documentation |
Inserts a box into a list of boxes and positions it relative to the surrounding boxes.
insert(x, element, ..., after = NULL, before = NULL)
## Default S3 method:
insert(x, element, ..., after = NULL, before = NULL)
## S3 method for class 'Gmisc_list_of_boxes'
insert(x, element, ..., after = NULL, before = NULL)
x |
A 'Gmisc_list_of_boxes'. |
element |
The new box object to insert. |
... |
Not used. |
after |
The name or index of the box after which to insert. |
before |
The name or index of the box before which to insert. |
The updated list of boxes with the new element inserted.
Other flowchart components:
align(),
append(),
boxGrob(),
boxHeaderGrob(),
boxPropGrob(),
boxShapes,
connectGrob(),
coords(),
distance(),
flowchart(),
move(),
moveBox(),
spread()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.