View source: R/boxGrobs_labelConnector.R
| setConnectorLabels | R Documentation |
Store labels and presentation options on a connector object so labels are automatically drawn when the connector is printed.
setConnectorLabels(
con,
labels,
gp = gpar(cex = 0.9),
bg_gp = gpar(fill = "white", col = NA),
x_offset = unit(0, "mm"),
y_offset = unit(0, "mm")
)
con |
A connector (a 'connect_boxes' grob or 'connect_boxes_list'). |
labels |
Character vector of labels (recycled to match connector length). |
gp |
A 'gpar' for label text. |
bg_gp |
A 'gpar' for label background. |
x_offset |
Unit offsets for label placement. |
y_offset |
Unit offsets for label placement. |
The connector object with attributes set (invisibly).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.